==> haskell-hit-0.6.3-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-9UDbFXkstNHLyLVfPFDoGF
key: hit-0.6.3-9UDbFXkstNHLyLVfPFDoGF
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Git Data.Git.Delta Data.Git.Diff Data.Git.Named Data.Git.Ref
    Data.Git.Repository Data.Git.Revision Data.Git.Storage
    Data.Git.Storage.Loose Data.Git.Storage.Object
    Data.Git.Storage.Pack Data.Git.Storage.PackIndex Data.Git.Types
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: de1f2d5ae0003762a3037b13fecb8986
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hit-0.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hit
hs-libraries: HShit-0.6.3-9UDbFXkstNHLyLVfPFDoGF
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH
    parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1 containers-0.5.10.2
    system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v
    system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V
    cryptohash-0.11.9-AuUIwcRUhl0JeUP5h4dr1o
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    zlib-bindings-0.1.1.5-KhoXB4j3i0U2hJZzgQ5LDj
    hourglass-0.2.10-F9F0uBDufctEafTNs2clkC
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    patience-0.1.1-26vcEH4XVheD55wNjzC8dW
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH=1e5250700950658eff033f7537304029
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=ac5e6b578591765d59beabaa71c9486d
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v=aecef6afad48762bf3e2300197e63ef4
             system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V=d2435ba451e5ce483df5a92e9e04d122
             cryptohash-0.11.9-AuUIwcRUhl0JeUP5h4dr1o=f724b9130a5f265433441f32d261e978
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=71e809b45e9d2afb17d0dfafd165b73c
             zlib-bindings-0.1.1.5-KhoXB4j3i0U2hJZzgQ5LDj=5632ebc91addece6595f112996d95c7d
             hourglass-0.2.10-F9F0uBDufctEafTNs2clkC=74e7f8ca68999c4d73ab52a4d4a8b2a3
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             patience-0.1.1-26vcEH4XVheD55wNjzC8dW=0cea22522a81db0a6266739b72f691c7
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hit-0.6.3-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-JWQfOsLyNyN1ml1Il1yiBj
key: hit-0.6.3-JWQfOsLyNyN1ml1Il1yiBj
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Git Data.Git.Delta Data.Git.Diff Data.Git.Named Data.Git.Ref
    Data.Git.Repository Data.Git.Revision Data.Git.Storage
    Data.Git.Storage.Loose Data.Git.Storage.Object
    Data.Git.Storage.Pack Data.Git.Storage.PackIndex Data.Git.Types
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: 0b3b2ac16cbb3344c26a4a49bffdb2f0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hit-0.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hit
hs-libraries: HShit-0.6.3-JWQfOsLyNyN1ml1Il1yiBj
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7 containers-0.5.10.2
    system-filepath-0.4.13.4-1SCOVWlmVKv3tFcatX70u1
    system-fileio-0.3.16.3-1AX8fnJlhIS16OAZu2n7aY
    cryptohash-0.11.9-KwFFxgUy4QKJVt4idcGzpE
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    zlib-bindings-0.1.1.5-KhoXB4j3i0U2hJZzgQ5LDj
    hourglass-0.2.10-F9F0uBDufctEafTNs2clkC
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    patience-0.1.1-26vcEH4XVheD55wNjzC8dW
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT=969f51e12ac15d411e4c04135fb32864
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=de60442ea6c5324e39bc534a733c07dd
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             system-filepath-0.4.13.4-1SCOVWlmVKv3tFcatX70u1=6bef6c2c5c0070d150805fc1f9f8b1de
             system-fileio-0.3.16.3-1AX8fnJlhIS16OAZu2n7aY=ed483908f9819f319f0089c6dd5951ba
             cryptohash-0.11.9-KwFFxgUy4QKJVt4idcGzpE=045e90cbc35f0d20c1b5f63e512cedfc
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=71e809b45e9d2afb17d0dfafd165b73c
             zlib-bindings-0.1.1.5-KhoXB4j3i0U2hJZzgQ5LDj=5632ebc91addece6595f112996d95c7d
             hourglass-0.2.10-F9F0uBDufctEafTNs2clkC=74e7f8ca68999c4d73ab52a4d4a8b2a3
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             patience-0.1.1-26vcEH4XVheD55wNjzC8dW=0cea22522a81db0a6266739b72f691c7
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
